@@ -23,6 +23,40 @@
   */
 #include "rsync.h"
 
+static FILE *logfile;
+
+
+/****************************************************************************
+  return the date and time as a string
+****************************************************************************/
+static char *timestring(void )
+{
+	static char TimeBuf[200];
+	time_t t = time(NULL);
+	struct tm *tm = localtime(&t);
+
+#ifdef HAVE_STRFTIME
+	strftime(TimeBuf,sizeof(TimeBuf)-1,"%Y/%m/%d %T",tm);
+#else
+	strlcpy(TimeBuf, asctime(tm), sizeof(TimeBuf)-1);
+#endif
+
+	if (TimeBuf[strlen(TimeBuf)-1] == '\n') {
+		TimeBuf[strlen(TimeBuf)-1] = 0;
+	}
+
+	return(TimeBuf);
+}
+
+static void logit(int priority, char *buf)
+{
+	if (logfile) {
+		fprintf(logfile,"%s  %s", timestring(), buf);
+		fflush(logfile);
+	} else {
+		syslog(priority, "%s", buf);
+	}
+}
 
 void log_open(void)
 {
@@ -33,6 +67,11 @@ void log_open(void)
 	if (initialised) return;
 	initialised = 1;
 
+	if (lp_log_file()) {
+		logfile = fopen(lp_log_file(), "a");
+		return;
+	}
+
 #ifdef LOG_NDELAY
 	options |= LOG_NDELAY;
 #endif
@@ -44,7 +83,7 @@ void log_open(void)
 #endif
 
 #ifndef LOG_NDELAY
-	syslog(LOG_INFO,"rsyncd started\n");
+	logit(LOG_INFO,"rsyncd started\n");
 #endif
 
 	/* this looks pointless, but it is needed in order for the
@@ -86,7 +125,7 @@ void rprintf(int fd, const char *format, ...)
 
 		log_open();
 		if (!io_multiplex_write(fd, buf, strlen(buf))) {
-			syslog(priority, "%s", buf);
+			logit(priority, buf);
 		}
 
 		depth--;
